@@ -1,6 +1,5 @@
-function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
-
-function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
+import _defineProperty from "@babel/runtime/helpers/defineProperty";
+import _extends from "@babel/runtime/helpers/extends";
 
 /**
  * Copyright IBM Corp. 2016, 2018
@@ -13,6 +12,7 @@ import classNames from 'classnames';
 import { action } from '@storybook/addon-actions';
 import { withKnobs, boolean, text } from '@storybook/addon-knobs';
 import Checkbox from '../Checkbox';
+import Button from '../../components/Button';
 import CheckboxSkeleton from '../Checkbox/Checkbox.Skeleton';
 import { settings } from 'carbon-components';
 import mdx from './Checkbox.mdx';
@@ -31,6 +31,39 @@ export default {
     }
   }
 };
+export var checkboxNativeValidation = function checkboxNativeValidation() {
+  function onSubmit(e) {
+    e.preventDefault();
+    var cb = e.target.querySelector('input[type=checkbox]');
+
+    if (cb.checked === false) {
+      cb.setCustomValidity('Privacy policy has to be accepted.');
+      cb.reportValidity();
+      return;
+    }
+
+    alert('submitted');
+  }
+
+  function onChange(e) {
+    e.target.setCustomValidity('');
+  }
+
+  return /*#__PURE__*/React.createElement("form", {
+    style: {
+      margin: '2em'
+    },
+    onSubmit: onSubmit,
+    onChange: onChange
+  }, /*#__PURE__*/React.createElement("legend", {
+    className: "".concat(prefix, "--label")
+  }, "Validation example"), /*#__PURE__*/React.createElement(Checkbox, {
+    id: "cb",
+    labelText: "Accept privacy policy"
+  }), /*#__PURE__*/React.createElement(Button, {
+    type: "submit"
+  }, "Submit"));
+};
 export var checkbox = function checkbox() {
   return /*#__PURE__*/React.createElement("fieldset", {
     className: "".concat(prefix, "--fieldset")
