@@ -1,5 +1,7 @@
 "use strict";
 
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
+
 require("carbon-components/scss/components/link/_link.scss");
 
 var _iconsReact = require("@carbon/icons-react");
@@ -10,8 +12,6 @@ var _react2 = require("@cypress/react");
 
 var _Link = _interopRequireDefault(require("../Link"));
 
-function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
-
 /**
  * Copyright IBM Corp. 2016, 2018
  *
