@@ -1,5 +1,7 @@
 "use strict";
 
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
+
 var _react = _interopRequireDefault(require("react"));
 
 var _iconsReact = require("@carbon/icons-react");
@@ -14,8 +16,6 @@ var _enzyme = require("enzyme");
 
 var _carbonComponents = require("carbon-components");
 
-function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
-
 /**
  * Copyright IBM Corp. 2016, 2018
  *
