@@ -1,5 +1,7 @@
 "use strict";
 
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
+
 var _react = _interopRequireDefault(require("react"));
 
 var _iconsReact = require("@carbon/icons-react");
@@ -12,8 +14,6 @@ var _enzyme = require("enzyme");
 
 var _carbonComponents = require("carbon-components");
 
-function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
-
 /**
  * Copyright IBM Corp. 2016, 2018
  *
@@ -171,11 +171,13 @@ describe('Search', function () {
     describe('enabled textinput', function () {
       var onClick = jest.fn();
       var onChange = jest.fn();
+      var onClear = jest.fn();
       var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_Search.default, {
         id: "test",
         labelText: "testlabel",
         onClick: onClick,
-        onChange: onChange
+        onChange: onChange,
+        onClear: onClear
       }));
       var input = wrapper.find('input');
       var eventObject = {
@@ -191,6 +193,22 @@ describe('Search', function () {
         input.simulate('change', eventObject);
         expect(onChange).toHaveBeenCalledWith(eventObject);
       });
+      it('should invoke onClear when input value is cleared', function () {
+        wrapper.setProps({
+          value: 'test'
+        });
+        var focus = jest.fn();
+        input.getElement().ref({
+          focus: focus
+        });
+        wrapper.find('button').simulate('click', {
+          target: {
+            value: 'test'
+          }
+        });
+        expect(onClear).toHaveBeenCalled();
+        expect(focus).toHaveBeenCalled();
+      });
     });
   });
 });
